package com.jh.core.error;

import java.util.Collection;

import org.springframework.http.HttpStatus;
import org.springframework.web.server.ResponseStatusException;

public class ApiException extends ResponseStatusException implements ErrorStatus, ErrorMessages {

	private static final long serialVersionUID = 1L;

	private ErrorMessage[] errors;
	
	public ApiException(HttpStatus status, ErrorMessage...errorMessages) {
		super(status);
		this.errors = errorMessages;
	}

	public ApiException(HttpStatus status, Collection<ErrorMessage> errorMessages) {
		super(status);
		this.errors = errorMessages == null ? new ErrorMessage[0] : errorMessages.toArray(new ErrorMessage[0]);
	}
	
	public ApiException(HttpStatus status, String reason, ErrorMessage...errorMessages) {
		super(status, reason);
		this.errors = errorMessages;
	}

	public ApiException(HttpStatus status, String reason, Throwable cause, ErrorMessage...errorMessages) {
		super(status, reason, cause);
		this.errors = errorMessages;
	}
	
	@Override
	public ErrorMessage[] getErrorMessages() {
		return errors;
	}

	@Override
	public HttpStatus getErrorStatus() {
		return getStatus();
	}

}
