package com.jh.core.error;

import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * The Class ErrorMessage.
 */
public class ErrorMessage {
	
	public static final String CODE_VALUE_REQUIRED = "VALUE_REQUIRED";
	
	public static final String CODE_NOT_FOUND = "NOT_FOUND";
	
    /** The field. */
    private String field;
    
    /** The code. */
    private String code;
    
    /** The message. */
    @JsonProperty("msg")
    private String message;

    private Object payload;
    
    /**
     * Instantiates a new error message.
     */
    private ErrorMessage() {
    }
    

    /* builder methods */
    
    /**
     * Constructs error message with field, code and message .
     *
     * @param field the field
     * @param code the code
     * @param message the message
     * @return the error message
     */
    public static ErrorMessage withFieldCodeMessage(String field, String code, String message) {
    	ErrorMessage em = new ErrorMessage();
    	em.field = field;
    	em.code = code;
    	em.message = message;
    	return em;
    }
    
    
    /**
     * Constructs error message with field, code and message .
     *
     * @param field the field
     * @param message the message
     * @return the error message
     */
    public static ErrorMessage withFieldMessage(String field, String message) {
    	ErrorMessage em = new ErrorMessage();
    	em.field = field;
    	em.message = message;
    	return em;
    }
    
    
    /**
     * Constructs error message with field and code .
     *
     * @param field the field
     * @param code the code
     * @return the error message
     */
    public static ErrorMessage withFieldCode(String field, String code) {
    	ErrorMessage em = new ErrorMessage();
    	em.field = field;
    	em.code = code;
    	return em;
    }
    
    
    /**
     * Constructs error message with code and message .
     *
     * @param code the code
     * @param message the message
     * @return the error message
     */
    public static ErrorMessage withCodeMessage(String code, String message) {
    	ErrorMessage em = new ErrorMessage();
    	em.code = code;
    	em.message = message;
    	return em;
    }

    public static ErrorMessage withCodePayload(String code, Object payload) {
        ErrorMessage em = new ErrorMessage();
        em.code = code;
        em.payload = payload;
        return em;
    }

    public static ErrorMessage withFieldCodePayload(String field, String code, Object payload) {
        ErrorMessage em = new ErrorMessage();
        em.field = field;
        em.code = code;
        em.payload = payload;
        return em;
    }

    public static ErrorMessage withFieldCodeMessagePayload(String field, String code, String message, Object payload) {
        ErrorMessage em = new ErrorMessage();
        em.field = field;
        em.code = code;
        em.payload = payload;
        em.message = message;
        return em;
    }

    public static ErrorMessage withMessagePayload(String message, Object payload) {
        ErrorMessage em = new ErrorMessage();
        em.payload = payload;
        em.message = message;
        return em;
    }

    public static ErrorMessage withFieldMessagePayload(String field, String message, Object payload) {
        ErrorMessage em = new ErrorMessage();
        em.field = field;
        em.payload = payload;
        em.message = message;
        return em;
    }

    /**
     * With message.
     *
     * @param message the message
     * @return the error message
     */
    public static ErrorMessage withMessage(String message) {
        ErrorMessage em = new ErrorMessage();
        em.message = message;
        return em;
    }
    

    /**
     * With code.
     *
     * @param code the code
     * @return the error message
     */
    public static ErrorMessage withCode(String code) {
        ErrorMessage em = new ErrorMessage();
        em.code = code;
        return em;
    }
    
    
    /* getters */
    
    /**
     * Gets the field.
     *
     * @return the field
     */
    public String getField() {
        return field;
    }

    /**
     * Gets the code.
     *
     * @return the code
     */
    public String getCode() {
        return code;
    }

    /**
     * Gets the message.
     *
     * @return the message
     */
    public String getMessage() {
        return message;
    }

    public Object getPayload() {
        return payload;
    }
}